pub struct StorageCacheConfig {
pub blob_cache_size: usize,
pub confirmed_block_cache_size: usize,
pub certificate_cache_size: usize,
pub certificate_raw_cache_size: usize,
pub event_cache_size: usize,
pub block_hash_by_height_cache_size: usize,
pub cache_cleanup_interval_secs: u64,
}Expand description
Individual cache sizes for each ValueCache in DbStorage.
Fields
blob_cache_size: usizeThe maximum number of blobs held in the blob cache.
confirmed_block_cache_size: usizeThe maximum number of confirmed blocks held in the confirmed-block cache.
certificate_cache_size: usizeThe maximum number of certificates held in the certificate cache.
certificate_raw_cache_size: usizeThe maximum number of raw certificates held in the raw-certificate cache.
event_cache_size: usizeThe maximum number of events held in the event cache.
block_hash_by_height_cache_size: usizeThe maximum number of block hashes to cache, keyed by (chain, height).
cache_cleanup_interval_secs: u64The interval, in seconds, between cache cleanup passes.