pub struct StorageConfig {
pub inner_storage_config: InnerStorageConfig,
pub namespace: String,
}Expand description
The description of a storage implementation.
Fields
inner_storage_config: InnerStorageConfigThe inner storage config.
namespace: StringThe namespace used
Implementations
Sourceimpl StorageConfig
impl StorageConfig
Sourcepub fn maybe_append_shard_path(&mut self, shard: usize) -> Result<()>
pub fn maybe_append_shard_path(&mut self, shard: usize) -> Result<()>
Appends a per-shard subdirectory to the path, for backends that store data on disk.
Sourcepub fn add_common_storage_options(
&self,
options: &CommonStorageOptions,
) -> Result<StoreConfig, Error>
pub fn add_common_storage_options( &self, options: &CommonStorageOptions, ) -> Result<StoreConfig, Error>
The addition of the common config to get a full configuration