Crate linera_storage_runtime

Crate linera_storage_runtime 

Storage configuration and runtime infrastructure for the Linera protocol.

Structs

AssertStorageV1
CommonStorageOptions
StorageCacheConfig
Individual cache sizes for each ValueCache in DbStorage.
StorageConfig
The description of a storage implementation.
StorageMigration

Enums

InnerStorageConfig
The description of a storage implementation.
StoreConfig
The configuration of the key value store in use.

Traits

Runnable
RunnableWithStore

Type Aliases

StorageCacheSizes
Backward-compatible alias.