Crate linera_storage_runtime

Crate linera_storage_runtime 

Storage configuration and runtime infrastructure for the Linera protocol.

Structs

AssertStorageV1
A store-level job that asserts the storage is already at version 1.
CommonStorageOptions
Command-line options shared by all storage backends.
StorageCacheConfig
Individual cache sizes for each ValueCache in DbStorage.
StorageConfig
The description of a storage implementation.
StorageMigration
A store-level job that migrates the storage to the latest version if needed.

Enums

InnerStorageConfig
The description of a storage implementation.
StoreConfig
The configuration of the key value store in use.

Traits

Runnable
A job that runs against a connected, high-level Storage.
RunnableWithStore
A job that runs directly against a key-value store, without a full Storage.

Type Aliases

StorageCacheSizes
Backward-compatible alias.