Storage configuration and runtime infrastructure for the Linera protocol.
Structs
- Assert
Storage V1 - A store-level job that asserts the storage is already at version 1.
- Common
Storage Options - Command-line options shared by all storage backends.
- Storage
Cache Config - Individual cache sizes for each
ValueCacheinDbStorage. - Storage
Config - The description of a storage implementation.
- Storage
Migration - A store-level job that migrates the storage to the latest version if needed.
Enums
- Inner
Storage Config - The description of a storage implementation.
- Store
Config - The configuration of the key value store in use.
Traits
- Runnable
- A job that runs against a connected, high-level
Storage. - Runnable
With Store - A job that runs directly against a key-value store, without a full
Storage.
Type Aliases
- Storage
Cache Sizes - Backward-compatible alias.