pub struct CommonStorageOptions {Show 18 fields
pub storage_max_concurrent_queries: Option<usize>,
pub storage_max_stream_queries: usize,
pub storage_max_cache_size: usize,
pub storage_max_value_entry_size: usize,
pub storage_max_find_keys_entry_size: usize,
pub storage_max_find_key_values_entry_size: usize,
pub storage_max_cache_entries: usize,
pub storage_max_cache_value_size: usize,
pub storage_max_cache_find_keys_size: usize,
pub storage_max_cache_find_key_values_size: usize,
pub blob_cache_size: usize,
pub confirmed_block_cache_size: usize,
pub certificate_cache_size: usize,
pub certificate_raw_cache_size: usize,
pub event_cache_size: usize,
pub block_cache_size: usize,
pub execution_state_cache_size: usize,
pub storage_replication_factor: u32,
}Fields
storage_max_concurrent_queries: Option<usize>The maximal number of simultaneous queries to the database
storage_max_stream_queries: usizeThe maximal number of simultaneous stream queries to the database
storage_max_cache_size: usizeThe maximal memory used in the storage cache.
storage_max_value_entry_size: usizeThe maximal size of a value entry in the storage cache.
storage_max_find_keys_entry_size: usizeThe maximal size of a find-keys entry in the storage cache.
storage_max_find_key_values_entry_size: usizeThe maximal size of a find-key-values entry in the storage cache.
storage_max_cache_entries: usizeThe maximal number of entries in the storage cache.
storage_max_cache_value_size: usizeThe maximal memory used in the value cache.
storage_max_cache_find_keys_size: usizeThe maximal memory used in the find_keys_by_prefix cache.
storage_max_cache_find_key_values_size: usizeThe maximal memory used in the find_key_values_by_prefix cache.
blob_cache_size: usizeThe maximal number of entries in the blob cache.
confirmed_block_cache_size: usizeThe maximal number of entries in the confirmed block cache.
certificate_cache_size: usizeThe maximal number of entries in the confirmed block certificate cache.
certificate_raw_cache_size: usizeThe maximal number of entries in the raw certificate cache.
event_cache_size: usizeThe maximal number of entries in the event cache.
block_cache_size: usizeThe number of entries in the block cache.
execution_state_cache_size: usizeThe number of entries in the execution state cache.
storage_replication_factor: u32The replication factor for the keyspace
Implementations
Sourceimpl CommonStorageOptions
impl CommonStorageOptions
pub fn storage_cache_sizes(&self) -> StorageCacheSizes
pub fn storage_cache_config(&self) -> ViewsStorageCacheConfig
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Returns options matching the clap-defined defaults.